@@ -11,6 +11,9 @@ from tqdm import tqdm
 
 DATA_DIR = os.path.expanduser(os.path.join('~', 'nessvec-data'))
 
+if not os.path.isdir(DATA_DIR):
+    os.mkdir(DATA_DIR)
+
 GLOVE_URL_TEMPLATE = 'http://nlp.stanford.edu/data/glove.{size}B.zip'
 # size: 6B | 42B | 84B | twitter.27B
 
